@@ -1,19 +1,46 @@
+import re
 import time
 import uuid
 from enum import IntEnum
-from typing import Dict
+from typing import Dict, Set
 
-import fps  # type: ignore
-from fastapi import APIRouter, WebSocket, WebSocketDisconnect
+from fps.hooks import register_router  # type: ignore
+from fastapi import APIRouter, WebSocket, WebSocketDisconnect, Depends, status
+import fastapi
+
+from fps_auth.routes import cookie_authentication  # type: ignore
+from fps_auth.models import user_db  # type: ignore
+from fps_auth.config import get_auth_config  # type: ignore
 
 router = APIRouter()
 
 
-@router.websocket("/api/yjs/{type}:{name}")
-async def websocket_endpoint(websocket: WebSocket, type: str, name: str):
-    await websocket.accept()
-    socket = YjsEchoWebSocket(websocket)
-    await socket.open(name)
+def get_path_param_names(path: str) -> Set[str]:
+    return {name.split(":")[0] for name in re.findall("{(.*?)}", path)}
+
+
+# FIXME: remove the patch when https://github.com/tiangolo/fastapi/pull/3879 is merged
+fastapi.utils.get_path_param_names.__code__ = get_path_param_names.__code__
+
+
+@router.websocket("/api/yjs/{type}:{path:path}")
+async def websocket_endpoint(
+    websocket: WebSocket, type, path, auth_config=Depends(get_auth_config)
+):
+    accept_websocket = False
+    if auth_config.mode == "noauth":
+        accept_websocket = True
+    elif "fastapiusersauth" in websocket._cookies:
+        cookie = websocket._cookies["fastapiusersauth"]
+        user = await cookie_authentication(cookie, user_db)
+        if user:
+            accept_websocket = True
+    if accept_websocket:
+        await websocket.accept()
+        socket = YjsEchoWebSocket(websocket)
+        await socket.open(path)
+    else:
+        await websocket.close(code=status.WS_1008_POLICY_VIOLATION)
 
 
 # The y-protocol defines messages types that just need to be propagated to all other peers.
@@ -120,4 +147,4 @@ class YjsEchoWebSocket:
                 # print("[YJSEchoWS]: close room " + self.room_id)
 
 
-r = fps.hooks.register_router(router)
+r = register_router(router)
